@@ -353,9 +353,10 @@ class SpecimenCollection(ContentSequence):
 class SpecimenSampling(ContentSequence):
 
     """Sequence of structured reporting content item describing a specimen
-    sampling procedure according to structured reporting template TID 8002
+    sampling procedure according to structured reporting template
+    `TID 8002 <http://dicom.nema.org/medical/dicom/current/output/chtml/part16/chapter_C.html#sect_TID_8002>`_
     Specimen Sampling.
-    """
+    """  # noqa E501
 
     def __init__(
             self,
@@ -410,9 +411,10 @@ class SpecimenSampling(ContentSequence):
 class SpecimenStaining(ContentSequence):
 
     """Sequence of structured reporting content item describing a specimen
-    staining procedure according to structured reporting template TID 8003
+    staining procedure according to structured reporting template
+    `TID 8003 <http://dicom.nema.org/medical/dicom/current/output/chtml/part16/chapter_C.html#sect_TID_8003>`_
     Specimen Staining.
-    """
+    """  # noqa E501
 
     def __init__(
             self,
@@ -438,8 +440,10 @@ class SpecimenStaining(ContentSequence):
 class SpecimenPreparationStep(ContentSequence):
 
     """Dataset describing a specimen preparation step according to
-    structured reporting template TID 8001 Specimen Preparation.
-    """
+    structured reporting template
+    `TID 8001 <http://dicom.nema.org/medical/dicom/current/output/chtml/part16/chapter_C.html#sect_TID_8001>`_
+    Specimen Preparation.
+    """  # noqa E501
 
     def __init__(
             self,
